@@ -116,7 +116,7 @@ struct ModResult {
  * and numerical comparisons in preprocessor macros if they wish to support
  * multiple versions of InspIRCd in one file.
  */
-#define INSPIRCD_VERSION_API 10
+#define INSPIRCD_VERSION_API 11
 
 /**
  * This #define allows us to call a method in all
@@ -332,7 +332,7 @@ enum Implementation
 	I_OnUserPostNick, I_OnPreMode, I_On005Numeric, I_OnKill, I_OnRemoteKill, I_OnLoadModule,
 	I_OnUnloadModule, I_OnBackgroundTimer, I_OnPreCommand, I_OnCheckReady, I_OnCheckInvite,
 	I_OnRawMode, I_OnCheckKey, I_OnCheckLimit, I_OnCheckBan, I_OnCheckChannelBan, I_OnExtBanCheck,
-	I_OnStats, I_OnChangeLocalUserHost, I_OnPreTopicChange,
+	I_OnStats, I_OnChangeLocalUserHost, I_OnPreTopicChange, I_OnPostDeoper,
 	I_OnPostTopicChange, I_OnEvent, I_OnGlobalOper, I_OnPostConnect, I_OnAddBan,
 	I_OnDelBan, I_OnChangeLocalUserGECOS, I_OnUserRegister, I_OnChannelPreDelete, I_OnChannelDelete,
 	I_OnPostOper, I_OnSyncNetwork, I_OnSetAway, I_OnPostCommand, I_OnPostJoin,
@@ -555,6 +555,11 @@ class CoreExport Module : public classbase, public usecountbase
 	 */
 	virtual void OnPostOper(User* user, const std::string &opername, const std::string &opertype);
 
+	/** Called after a user deopers locally.
+	 * @param user The user who has deopered.
+	 */
+	virtual void OnPostDeoper(User* user);
+
 	/** Called whenever a user types /INFO.
 	 * The User will contain the information of the user who typed the command. Modules may use this
 	 * method to output their own credits in /INFO (which is the ircd's version of an about box).
