@@ -80,7 +80,8 @@ class BanRedirect : public ModeWatcher
 
 			if(adding && (channel->bans.size() > static_cast<unsigned>(maxbans)))
 			{
-				source->WriteNumeric(478, "%s %s :Channel ban list for %s is full (maximum entries for this channel is %ld)", source->nick.c_str(), channel->name.c_str(), channel->name.c_str(), maxbans);
+				source->WriteNumeric(478, "%s %s %c :Channel ban list for %s is full (maximum entries for this channel is %ld)",
+					source->nick.c_str(), channel->name.c_str(), mode, channel->name.c_str(), maxbans);
 				return false;
 			}
 
@@ -178,6 +179,21 @@ class BanRedirect : public ModeWatcher
 						redirects = new BanRedirectList;
 						extItem.set(channel, redirects);
 					}
+					else
+					{
+						for (BanRedirectList::iterator redir = redirects->begin(); redir != redirects->end(); ++redir)
+						{
+							// Mimic the functionality used when removing the mode
+							if ((irc::string(redir->targetchan.c_str()) == irc::string(mask[CHAN].c_str())) && (irc::string(redir->banmask.c_str()) == irc::string(param.c_str())))
+							{
+								// Make sure the +b handler will still set the right ban
+								param.append(mask[CHAN]);
+								// Silently ignore the duplicate and don't set metadata
+								// This still allows channel ops to set/unset a redirect ban to clear "ghost" redirects
+								return true;
+							}
+						}
+					}
 
 					/* Here 'param' doesn't have the channel on it yet */
 					redirects->push_back(BanRedirectEntry(mask[CHAN], param));
