@@ -130,7 +130,7 @@ class ModuleXLineDB : public Module
 			{
 				XLine* line = i->second;
 				fprintf(f, "LINE %s %s %s %lu %lu :%s\n", line->type.c_str(), line->Displayable(),
-					ServerInstance->Config->ServerName.c_str(), (unsigned long)line->set_time, (unsigned long)line->duration, line->reason.c_str());
+					line->source.c_str(), (unsigned long)line->set_time, (unsigned long)line->duration, line->reason.c_str());
 			}
 		}
 
